Index: src/wp-admin/js/customize-controls.js
===================================================================
--- src/wp-admin/js/customize-controls.js	(revision 27648)
+++ src/wp-admin/js/customize-controls.js	(working copy)
@@ -918,13 +918,14 @@
 			body = $( document.body ),
 			overlay = body.children('.wp-full-overlay');
 
 		// Prevent the form from saving when enter is pressed.
 		$('#customize-controls').on( 'keydown', function( e ) {
-			if ( $( e.target ).is('textarea') )
-				return;
+			var isEnter = ( 13 === e.which ),
+				$el = $( e.target );
 
-			if ( 13 === e.which ) // Enter
+			if ( isEnter && ( $el.is( 'input:not([type=button])' ) || $el.is( 'select' ) ) ) {
 				e.preventDefault();
+			}
 		});
 
 		// Initialize Previewer
@@ -918,13 +918,14 @@
 			overlay = body.children('.wp-full-overlay');
 
-		// Prevent the form from saving when enter is pressed.
+		// Prevent the form from saving when enter is pressed on an input element.
 		$('#customize-controls').on( 'keydown', function( e ) {
